@@ -21,8 +21,7 @@ async def search(
             query=search_parameters.query,
             offset=search_parameters.offset,
             limit=search_parameters.limit,
-            filters=search_parameters.filters,
-            facet_filters=search_parameters.facet_filters,
+            filter=search_parameters.filter,
             facets_distribution=search_parameters.facets_distribution,
             attributes_to_retrieve=search_parameters.attributes_to_retrieve,
             attributes_to_crop=search_parameters.attributes_to_crop,
